package com.mamezou.spring.jdbc;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;

import org.springframework.jdbc.core.namedparam.BeanPropertySqlParameterSource;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.jdbc.core.simple.ParameterizedRowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;
import org.springframework.jdbc.core.support.JdbcDaoSupport;

public class DaoSupportTest extends SpringJdbcTest {
   

    public void test_named_simple_mix_dao() throws Exception {
        MixJdbcDao dao = new MixJdbcDao();
        dao.setDataSource(ds);

        // findAllAuthor with SimpleJdbcTemplate
        List<Author> result = dao.findAllAuthor();
        Author actual = result.get(1);
        assertEquals(new Author(2, ""),actual);

        Author expected = new Author(2, "哤");
        // updateAuthor withe NamedParameterJdbcTemplate
        dao.updateAuthor(expected);

        List<Author> resultAfterUpdate = dao.findAllAuthor();
        Author actualAfterUpdate = resultAfterUpdate.get(1);
        assertEquals(expected,actualAfterUpdate);

    }

    private static class MixJdbcDao extends JdbcDaoSupport {

        private NamedParameterJdbcTemplate nameTemplate = null;

        private SimpleJdbcTemplate simpleTemplate = null;

        @Override
        protected void initTemplateConfig() {
            super.initTemplateConfig();
            nameTemplate = new NamedParameterJdbcTemplate(getJdbcTemplate());
            simpleTemplate = new SimpleJdbcTemplate(getJdbcTemplate());
        }

        public List<Author> findAllAuthor() {
            return simpleTemplate.query("select id,name from author",
                    new ParameterizedRowMapper<Author>() {
                        public Author mapRow(ResultSet rs, int rowNum)
                                throws SQLException {
                            Author author = new Author();
                            author.setId(rs.getInt("id"));
                            author.setName(rs.getString("name"));
                            return author;
                        }
                    });
        }

        public int updateAuthor(Author updated) {
            return nameTemplate.update(
                    "update Author set name=:name where id = :id",
                    new BeanPropertySqlParameterSource(updated));
        }
    }

}
