package com.mamezou.spring.jdbc;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.HashMap;
import java.util.Map;

import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.namedparam.BeanPropertySqlParameterSource;
import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;

public class NamedParameterJdbcTemplateTest extends SpringJdbcTest {

    public void test_NamedParameterJdbcTemplate() throws Exception {

        NamedParameterJdbcTemplate template = new NamedParameterJdbcTemplate(ds);
        Map<String, Object> parameters = new HashMap<String, Object>();
        parameters.put("id", 2);
        Author actual = (Author) template.queryForObject(
                "select id,name from author where id = :id", parameters,
                new RowMapper() {

                    public Object mapRow(ResultSet rs, int rowNum)
                            throws SQLException {
                        Author author = new Author();
                        author.setId(rs.getInt("id"));
                        author.setName(rs.getString("name"));
                        return author;
                    }
                });

        assertEquals(new Author(2, ""), actual);
    }

    public void test_NamedParameterJdbcTemplateWithMapSqlParameterSource()
            throws Exception {

        NamedParameterJdbcTemplate template = new NamedParameterJdbcTemplate(ds);
        MapSqlParameterSource parameters = new MapSqlParameterSource();

        parameters.addValue("id", 2);
        Author actual = (Author) template.queryForObject(
                "select id,name from author where id = :id", parameters,
                new RowMapper() {

                    public Object mapRow(ResultSet rs, int rowNum)
                            throws SQLException {
                        Author author = new Author();
                        author.setId(rs.getInt("id"));
                        author.setName(rs.getString("name"));
                        return author;
                    }
                });

        assertEquals(new Author(2, ""), actual);
    }

    public void test_NamedParameterJdbcTemplate_with_BeanPropertySqlParameterSource()
            throws Exception {

        NamedParameterJdbcTemplate template = new NamedParameterJdbcTemplate(ds);

        Author param = new Author();
        param.setId(2);
        BeanPropertySqlParameterSource bps = new BeanPropertySqlParameterSource(
                param);

        Author actual = (Author) template.queryForObject(
                "select id,name from author where id = :id", bps,
                new RowMapper() {

                    public Object mapRow(ResultSet rs, int rowNum)
                            throws SQLException {
                        Author author = new Author();
                        author.setId(rs.getInt("id"));
                        author.setName(rs.getString("name"));
                        return author;
                    }
                });

        assertEquals(new Author(2, ""), actual);
    }

}
