package com.mamezou.spring.jdbc;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;
import java.util.Map;

import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.simple.ParameterizedRowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;

public class SimpleJdbcTemplateTest extends SpringJdbcTest {
   

    public void test_SimpleJdbcTemplate_queryForObject_withParameterizedRowMapper() throws Exception {
        SimpleJdbcTemplate templete = new SimpleJdbcTemplate(ds);
        Author actual = templete.queryForObject(
                "select id,name from author where id = ?",
                new ParameterizedRowMapper<Author>() {
                    public Author mapRow(ResultSet rs, int rowNum)
                            throws SQLException {
                        Author author = new Author();
                        author.setId(rs.getInt("id"));
                        author.setName(rs.getString("name"));
                        return author;
                    }
                }, 1);
        assertEquals(new Author(1, "哤"),actual);
    }

    public void test_SimpleJdbcTemplate_queryForObject() throws Exception {
        SimpleJdbcTemplate templete = new SimpleJdbcTemplate(ds);
        String actual = templete.queryForObject(
                "select name from author where id = ?",String.class,1);
        assertEquals("哤",actual);
    }
    
    public void test_SimpleJdbcTemplate_queryForList() throws Exception {
        SimpleJdbcTemplate template = new SimpleJdbcTemplate(ds);
        List actual = template.queryForList("select id,name from author");
        assertEquals(2, actual.size());
        Map row = (Map) actual.get(0);
        assertEquals(1, row.get("ID"));
        assertEquals("哤", row.get("NAME"));
    }
    
    public void test_SimpleJdbcTemplate_queryForMap() throws Exception {
        SimpleJdbcTemplate template = new SimpleJdbcTemplate(ds);
        Map actual = template.queryForMap("select id,name from author where id = ?",1);
        assertEquals(1, actual.get("ID"));
        assertEquals("哤", actual.get("NAME"));
    }
    
    public void test_oldStyle_JdbcTemplate() throws Exception {
        JdbcTemplate template = new JdbcTemplate(ds);
        Author actual = (Author) template.queryForObject(
                "select id,name from author where id = ?",
                new Object[] { Integer.valueOf(1) }, new RowMapper() {
                    public Object mapRow(ResultSet rs, int rowNum)
                            throws SQLException {
                        Author author = new Author();
                        author.setId(Integer.valueOf(rs.getInt("id")));
                        author.setName(rs.getString("name"));
                        return author;
                    }
                });
        assertEquals(new Author(1, "哤"),actual);
    }
}
