package com.mamezou.spring.jdbc;

import java.sql.Connection;
import java.sql.Statement;

import javax.sql.DataSource;

import org.hsqldb.Server;
import org.springframework.jdbc.datasource.DriverManagerDataSource;

import junit.framework.TestCase;

public abstract class SpringJdbcTest extends TestCase{
    protected DataSource ds;

    private Server server;

    @Override
    protected void setUp() throws Exception {
        server = new Server();
        server.setDatabaseName(0, "springjdbc");
        server
                .setDatabasePath(0,
                        "mem:springjdbc;sql.enforce_strict_size=true");
        server.setLogWriter(null);
        server.setErrWriter(null);
        server.start();

        ds = new DriverManagerDataSource("org.hsqldb.jdbcDriver",
                "jdbc:hsqldb:hsql://localhost/springjdbc", "sa", "");

        Connection conn = null;
        Statement stmt = null;
        try {
            conn = ds.getConnection();
            stmt = conn.createStatement();
    
            stmt.execute("drop table author if exists");
            stmt.execute("CREATE TABLE AUTHOR("
                    + "ID INTEGER NOT NULL IDENTITY PRIMARY KEY,"
                    + "NAME VARCHAR(12)," 
                    + "MAIL_ADDRESS VARCHAR(50)" + ")");
    
            stmt.execute("INSERT INTO AUTHOR VALUES(1,'哤','daizu@mamezou.com');");
            stmt.execute("INSERT INTO AUTHOR VALUES(2,'','azuki@mamezou.com');");
        } finally {
            try {
                if (stmt != null) {
                    stmt.close();
                }
            } finally {
                if (conn != null) {
                    conn.close();
                }
            }
        }
        super.setUp();
    }

    @Override
    protected void tearDown() throws Exception {
        server.stop();
        server = null;
        
        super.tearDown();
    }
    
}
